@@ -42,9 +42,9 @@ $^V eq v5.8.3
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Fri Aug 24 16:51:59 EEST 2007
+## Configuration time: Thu Mar 13 13:52:57 EET 2008
 ## Configured by     : Debian Project
-## Target system     : linux titano 2.6.18-4-686-bigmem #1 smp thu may 10 00:23:00 utc 2007 i686 gnulinux 
+## Target system     : linux eewi 2.6.18-5-686-bigmem #1 smp wed oct 3 01:22:56 utc 2007 i686 gnulinux 
 #
 ## Configure command line arguments.
 #PERL_PATCHLEVEL=
@@ -103,7 +103,7 @@ installprivlib='/usr/share/perl/5.8'
 libpth='/usr/local/lib /lib /usr/lib'
 libs='-lgdbm -lgdbm_compat -ldl -lm -lpthread -lc -lcrypt'
 osname='linux'
-osvers='2.6.18-4-686-bigmem'
+osvers='2.6.18-5-686-bigmem'
 prefix='/usr'
 privlibexp='/usr/share/perl/5.8'
 sharpbang='#!'
@@ -168,7 +168,7 @@ ccsymbols=''
 ccversion=''
 cf_by='Debian Project'
 cf_email='perl@packages.debian.org'
-cf_time='Fri Aug 24 16:51:59 EEST 2007'
+cf_time='Thu Mar 13 13:52:57 EET 2008'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -704,7 +704,7 @@ gzip='gzip'
 h_fcntl='false'
 h_sysfile='true'
 hint='recommended'
-hostcat='cat /etc/hosts'
+hostcat=''
 html1dir=' '
 html1direxp=''
 html3dir=' '
@@ -892,7 +892,7 @@ mv=''
 myarchname='i686-linux'
 mydomain=''
 myhostname='localhost'
-myuname='linux titano 2.6.18-4-686-bigmem #1 smp thu may 10 00:23:00 utc 2007 i686 gnulinux '
+myuname='linux eewi 2.6.18-5-686-bigmem #1 smp wed oct 3 01:22:56 utc 2007 i686 gnulinux '
 n='-n'
 need_va_copy='undef'
 netdb_hlen_type='size_t'
@@ -1307,7 +1307,7 @@ tie %Config, 'Config', {
     'libpth' => '/usr/local/lib /lib /usr/lib',
     'libs' => '-lgdbm -lgdbm_compat -ldl -lm -lpthread -lc -lcrypt',
     'osname' => 'linux',
-    'osvers' => '2.6.18-4-686-bigmem',
+    'osvers' => '2.6.18-5-686-bigmem',
     'prefix' => '/usr',
     'privlibexp' => '/usr/share/perl/5.8',
     'sharpbang' => '#!',
